# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/litepci/performance/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/litepci/performance/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Litepci\\Performance\\": "packages/litepci/performance/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Litepci\Performance\Providers\PerformanceServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Performance'  => Litepci\Performance\Facades\Performance::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Litepci\\PerformanceTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Litepci\Performance\Providers\PerformanceServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Litepci\Performance\Providers\PerformanceServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Litepci\Performance\Providers\PerformanceServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/performance/{modulename}

**User**

    http://path-to-route-folder/user/performance/{modulename}

**Public**

    http://path-to-route-folder/performances


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/performance/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/performance/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/performance/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/performance/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/performance/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/performance/{modulename}/{slug}
    METHOD: GET