<?php

namespace Litepci\Performance\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepci\Performance\Models\Performance;

class PerformancePolicy
{

    /**
     * Determine if the given user can view the performance.
     *
     * @param UserPolicy $user
     * @param Performance $performance
     *
     * @return bool
     */
    public function view(UserPolicy $user, Performance $performance)
    {
        if ($user->canDo('performance.performance.view') && $user->isAdmin()) {
            return true;
        }

        return $performance->user_id == user_id() && $performance->user_type == user_type();
    }

    /**
     * Determine if the given user can create a performance.
     *
     * @param UserPolicy $user
     * @param Performance $performance
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('performance.performance.create');
    }

    /**
     * Determine if the given user can update the given performance.
     *
     * @param UserPolicy $user
     * @param Performance $performance
     *
     * @return bool
     */
    public function update(UserPolicy $user, Performance $performance)
    {
        if ($user->canDo('performance.performance.edit') && $user->isAdmin()) {
            return true;
        }

        return $performance->user_id == user_id() && $performance->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given performance.
     *
     * @param UserPolicy $user
     * @param Performance $performance
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Performance $performance)
    {
        return $performance->user_id == user_id() && $performance->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given performance.
     *
     * @param UserPolicy $user
     * @param Performance $performance
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Performance $performance)
    {
        if ($user->canDo('performance.performance.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given performance.
     *
     * @param UserPolicy $user
     * @param Performance $performance
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Performance $performance)
    {
        if ($user->canDo('performance.performance.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
